@@ -1,18 +1,18 @@
-"""Configuration"""
-__all__ = [
-    'config',
-    'print_as_json',
-]
+__all__ = ['config']
 
 import json
-from os.path import join, dirname, realpath, isfile
-from os import listdir, makedirs
-import sys
-from typing import Dict, Any
 import re
+import sys
+from os import makedirs
+from os.path import join, dirname, realpath
+from typing import Dict, Any
 
 config : Dict[str, Any] = {}
 
+config.update({
+    'logging_enabled': False,
+})
+
 config.update({
     'module_dir': dirname(realpath(__file__)),
 })
@@ -26,10 +26,10 @@ config.update({
     'module': 'zsh_jupyter_kernel',
     'version': version,
     'description': 'Z shell kernel for Jupyter',
-    'author': 'Dan Oak',
-    'author_email': 'danylo.dubinin@gmail.com',
-    'license': 'GPL-3.0',
-    'github_url': 'https://github.com/danylo-dubinin/zsh-jupyter-kernel',
+    'author': 'dan oak',
+    'author_email': 'curly-brace-17@protonmail.com',
+    'license': '',
+    'github_url': 'https://github.com/dany-oak/zsh-jupyter-kernel',
     'keywords': [
         'jupyter',
         'ipython',
@@ -51,7 +51,7 @@ config.update({
 })
 
 config.update({
-    'python_version': '>=3',
+    'python_version': '>=3.10',
     # 'git_revision_hash': subprocess
     #     .check_output(['git', 'rev-parse', 'HEAD'])
     #     .decode()
@@ -72,19 +72,26 @@ with open(join(config['module_dir'], config['readme'])) as f:
         'content': readme_md,
         'type': 'text/markdown',
     }
-    config['long_description']['md_without_images'] = {
-        'content': re.sub(r'\n.*!\[.*screenshot.*\].*\n', '', readme_md),
+    config['long_description']['md_with_github_image_links'] = {
+        'content': re.sub(
+            r'(!\[.*screenshot.*])\((.*)\)',
+            r'\1(https://raw.githubusercontent.com/dan-oak/zsh-jupyter-kernel/master/\2)',
+            readme_md),
         'type': 'text/markdown',
     }
 
 config.update({
-    'logfile': join(config['log_dir'], 'kernel.log'),
-    'logging_formatter': # [logging]
-        '%(asctime)s | %(name)-10s | %(levelname)-6s | %(message)s',
     # 'log_level': "DEBUG",
     'log_level': "INFO",
 })
-makedirs(dirname(config['logfile']), exist_ok = True)
+
+if config['logging_enabled']:
+    config.update({
+        'logfile': join(config['log_dir'], 'kernel.log'),
+        'logging_formatter': # [logging]
+            '%(asctime)s | %(name)-10s | %(levelname)-6s | %(message)s',
+    })
+    makedirs(dirname(config['logfile']), exist_ok = True)
 
 config.update({
     'non_python_files': [
@@ -94,16 +101,6 @@ config.update({
         'version',
     ],
     'pexpect': { # [pexpect-spawn]
-        'cmd': 'zsh', 'args': [
-            '-o', 'INTERACTIVE',
-            '-o', 'NO_ZLE',
-            '-o', 'NO_BEEP',
-            '-o', 'TRANSIENT_RPROMPT',
-            '-o', 'NO_PROMPT_CR',
-            '-o', 'INTERACTIVE_COMMENTS',
-            # '-o', 'XTRACE',
-            # '-o', 'NO_RCS',
-        ], # [zsh-options]
         'encoding': 'utf-8',
         'codec_errors': 'replace', # [codecs]
         'timeout': None, # [pexpect-spawn-timeout]
@@ -128,17 +125,6 @@ config.update({
         ],
     },
     'kernel': {
-        'spec': { # [kernel-specs]
-            "argv": [
-                sys.executable,
-                    "-m", 'zsh_jupyter_kernel',
-                        "-f", "{connection_file}",
-            ],
-            "display_name": "Z shell",
-            "language": "zsh",
-            # "interrupt_mode": "message", # [interrupt]
-            "interrupt_mode": "signal",
-        },
         'code_completness': {'cmd': "zsh -nc '{}'"},
         'code_inspection': {'cmd': r"""zsh -c 'man -P "col -b" \'{}\\''"""},
         'code_completion': {'cmd': config['module_dir'] + "/capture.zsh '{}'"},
@@ -146,7 +132,8 @@ config.update({
             # Thanks to https://github.com/Valodim/zsh-capture-completion
     },
 })
-makedirs(dirname(config['pexpect']['logfile']), exist_ok = True)
+if config['logging_enabled']:
+    makedirs(dirname(config['pexpect']['logfile']), exist_ok = True)
 
 config['kernel']['info'] = {
     'protocol_version': '5.3',
@@ -170,29 +157,6 @@ config['kernel']['info'] = {
 with open(join(config['module_dir'], 'banner.txt'), 'r') as f:
     config['kernel']['info']['banner'] = f.read()
 
-def print_as_json():
+if __name__ == '__main__':
     print(json.dumps(config, indent = 4))
 
-if __name__ == '__main__':
-    print_as_json()
-
-# ## Reference
-# [pexpect-spawn]: https://pexpect.readthedocs.io/en/stable/api/pexpect.html#spawn-class
-# [pexpect-spawn-timeout]: https://pexpect.readthedocs.io/en/stable/api/pexpect.html?highlight=timeout#spawn-class
-# [codecs]: https://docs.python.org/3/library/codecs.html
-# [logging]: https://docs.python-guide.org/writing/logging/
-# [zsh-options]: https://linux.die.net/man/1/zshoptions
-# [zsh-functions]: http://zsh.sourceforge.net/Doc/Release/Functions.html
-# [zsh-bracketed-paste]: https://archive.zhimingwang.org/blog/2015-09-21-zsh-51-and-bracketed-paste.html
-#
-# [zsh-hooks]: http://zsh.sourceforge.net/Doc/Release/User-Contributions.html
-#   - Section "Manipulating Hook Functions"
-#   Different plugins (e.g. oh-my-zsh with custom themes) use
-#   `precmd`/`preexec` hooks to set prompts. `add-zsh-hook -D <hook> <pattern>`
-#   allows to delete all assosiated functions from a hook.
-#
-# [interrupt]: https://jupyter-client.readthedocs.io/en/latest/messaging.html#kernel-interrupt
-# Interrupt by message does not work now but works by signal. This is
-# confusing as hell to me as previously it was not working. Whatever...
-#
-# [kernel-specs]: https://jupyter-client.readthedocs.io/en/latest/kernels.html#kernelspecs
